@@ -25,20 +25,19 @@ class DeleteQualityRuleRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'DeleteQualityRule')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ProjectName(self):
+	def get_ProjectName(self): # String
 		return self.get_body_params().get('ProjectName')
 
-	def set_ProjectName(self,ProjectName):
+	def set_ProjectName(self, ProjectName):  # String
 		self.add_body_params('ProjectName', ProjectName)
-
-	def get_RuleId(self):
+	def get_RuleId(self): # Long
 		return self.get_body_params().get('RuleId')
 
-	def set_RuleId(self,RuleId):
-		self.add_body_params('RuleId', RuleId)
\ No newline at end of file
+	def set_RuleId(self, RuleId):  # Long
+		self.add_body_params('RuleId', RuleId)
